@@ -31,6 +31,9 @@ python_ver_atleast_39 = py_version >= (3, 9)
 
 
 class ImmutableMixin:
+    """
+    Helper for making a field immutable
+    """
     _field_definition = None
     _instance = None
 
@@ -49,7 +52,9 @@ class ImmutableMixin:
             raise ValueError("{}: Field is immutable".format(name))
 
 
-def make_signature(names, required, additional_properties, bases_params_by_name):
+def make_signature(
+    names, required, additional_properties, bases_params_by_name, bases_required
+):
     """
     Make a signature that will be used for the constructor of the Structure
     :param names: names of the properties
@@ -71,7 +76,7 @@ def make_signature(names, required, additional_properties, bases_params_by_name)
         [
             (name, param)
             for (name, param) in bases_params_by_name.items()
-            if name in required
+            if (name in required or name in bases_required)
         ]
     )
     non_default_args = list(
@@ -89,7 +94,7 @@ def make_signature(names, required, additional_properties, bases_params_by_name)
         [
             (name, param)
             for (name, param) in bases_params_by_name.items()
-            if name not in required
+            if (name not in required and name not in bases_required)
         ]
     )
     default_args = list({**default_args_for_bases, **default_args_for_class}.values())
@@ -146,7 +151,7 @@ def _check_for_final_violations(classes):
                     )
                 )
             if "ImmutableStructure" in globals() and is_sub_class(
-                    c, ImmutableStructure
+                c, ImmutableStructure
             ):
                 raise TypeError(
                     "Tried to extend {}, which is an ImmutableStructure. This is forbidden".format(
@@ -211,9 +216,9 @@ class UniqueMixin:
     def __manage_uniqueness__(self):
         myclass = self.__class__
         if (
-                getattr(myclass, MUST_BE_UNIQUE, False)
-                and len(getattr(myclass, "_ALL_INSTANCES", set()))
-                < MAX_NUMBER_OF_INSTANCES_TO_VERIFY_UNIQUENESS
+            getattr(myclass, MUST_BE_UNIQUE, False)
+            and len(getattr(myclass, "_ALL_INSTANCES", set()))
+            < MAX_NUMBER_OF_INSTANCES_TO_VERIFY_UNIQUENESS
         ):
             hash_of_instance = self.__hash__()
             if hash_of_instance in getattr(myclass, "_ALL_INSTANCES", set()):
@@ -237,17 +242,18 @@ class UniqueMixin:
             structure_class_name
         ]
         if (
-                getattr(self, MUST_BE_UNIQUE, False)
-                and len(instance_by_value_for_current_struct)
-                < MAX_NUMBER_OF_INSTANCES_TO_VERIFY_UNIQUENESS
+            getattr(self, MUST_BE_UNIQUE, False)
+            and len(instance_by_value_for_current_struct)
+            < MAX_NUMBER_OF_INSTANCES_TO_VERIFY_UNIQUENESS
         ):
             hash_of_field_val = value.__hash__()
             if (
-                    instance_by_value_for_current_struct.get(hash_of_field_val, instance)
-                    != instance
+                instance_by_value_for_current_struct.get(hash_of_field_val, instance)
+                != instance
             ):
                 raise ValueError(
-                    "Instance copy of field {} in {}, which is defined as unique. Instance is {}".format(
+                    "Instance copy of field {} in {}, which is defined as unique. "
+                    "Instance is {}".format(
                         field_name, structure_class_name, wrap_val(value)
                     )
                 )
@@ -321,13 +327,13 @@ class Field(UniqueMixin, metaclass=_FieldMeta):
             else owner.__dict__[self._name]
         )
         is_immutable = (
-                instance is not None
-                and getattr(instance, IS_IMMUTABLE, False)
-                or getattr(self, IS_IMMUTABLE, False)
+            instance is not None
+            and getattr(instance, IS_IMMUTABLE, False)
+            or getattr(self, IS_IMMUTABLE, False)
         )
         needs_defensive_copy = (
-                not isinstance(res, (ImmutableMixin, int, float, str, bool, enum.Enum))
-                or res is None
+            not isinstance(res, (ImmutableMixin, int, float, str, bool, enum.Enum))
+            or res is None
         )
         return deepcopy(res) if (is_immutable and needs_defensive_copy) else res
 
@@ -335,7 +341,7 @@ class Field(UniqueMixin, metaclass=_FieldMeta):
         if getattr(self, IS_IMMUTABLE, False) and self._name in instance.__dict__:
             raise ValueError("{}: Field is immutable".format(self._name))
         if getattr(self, IS_IMMUTABLE, False) and not getattr(
-                self, "_custom_deep_copy_implementation", False
+            self, "_custom_deep_copy_implementation", False
         ):
             try:
                 instance.__dict__[self._name] = deepcopy(value)
@@ -350,7 +356,7 @@ class Field(UniqueMixin, metaclass=_FieldMeta):
             instance.__dict__[self._name] = value
             instance.__manage__uniqueness_of_all_fields__()
         if getattr(instance, "_instantiated", False) and not getattr(
-                instance, "_skip_validation", False
+            instance, "_skip_validation", False
         ):
             instance.__validate__()
 
@@ -414,34 +420,34 @@ def _get_all_fields_by_name(cls):
 def _instantiate_fields_if_needed(cls_dict: dict, defaults: dict):
     for key, val in cls_dict.items():
         if (
-                key
-                not in {
-            REQUIRED_FIELDS,
-            ADDITIONAL_PROPERTIES,
-            IS_IMMUTABLE,
-            DEFAULTS,
-            OPTIONAL_FIELDS,
-            IGNORE_NONE_VALUES,
-        }
-                and not isinstance(val, Field)
-                and not key.startswith("__")
-                and (
+            key
+            not in {
+                REQUIRED_FIELDS,
+                ADDITIONAL_PROPERTIES,
+                IS_IMMUTABLE,
+                DEFAULTS,
+                OPTIONAL_FIELDS,
+                IGNORE_NONE_VALUES,
+            }
+            and not isinstance(val, Field)
+            and not key.startswith("__")
+            and (
                 Field in getattr(val, "__mro__", []) or is_function_returning_field(val)
-        )
+            )
         ):
             new_val = val(default=defaults[key]) if key in defaults else val()
             cls_dict[key] = new_val
 
 
 def _apply_default_and_update_required_not_to_include_fields_with_defaults(
-        cls_dict: dict, defaults: dict, fields: list
+    cls_dict: dict, defaults: dict, fields: list
 ):
     required_fields = set(cls_dict.get(REQUIRED_FIELDS, []))
     optional_fields = set(cls_dict.get(OPTIONAL_FIELDS, []))
     required_fields_predefined = REQUIRED_FIELDS in cls_dict
     for field_name in fields:
         if field_name in defaults and not getattr(
-                cls_dict[field_name], "_default", None
+            cls_dict[field_name], "_default", None
         ):
             cls_dict[field_name]._try_default_value(defaults[field_name])
             cls_dict[field_name]._default = defaults[field_name]
@@ -493,7 +499,13 @@ class StructMeta(type):
         required = cls_dict.get(REQUIRED_FIELDS, default_required)
         setattr(clsobj, REQUIRED_FIELDS, list(set(bases_required + required)))
         additional_props = cls_dict.get(ADDITIONAL_PROPERTIES, True)
-        sig = make_signature(clsobj._fields, required, additional_props, bases_params)
+        sig = make_signature(
+            clsobj._fields,
+            required,
+            additional_props,
+            bases_params,
+            bases_required=bases_required,
+        )
         setattr(clsobj, "__signature__", sig)
         return clsobj
 
@@ -549,15 +561,15 @@ def _type_is_generic(v):
     generic_alias = getattr(typing, "_GenericAlias", Foo)
     special_generic_alias = getattr(typing, "_SpecialGenericAlias", Foo)
     return (
-            (python_ver_36 and isinstance(v, typing_base))
-            or (
-                    python_ver_atleast_than_37
-                    and isinstance(v, (generic_alias, special_generic_alias))
-            )
-            or (
-                    python_ver_atleast_39
-                    and origin in {list, dict, tuple, set, frozenset, deque, typing.Union}
-            )
+        (python_ver_36 and isinstance(v, typing_base))
+        or (
+            python_ver_atleast_than_37
+            and isinstance(v, (generic_alias, special_generic_alias))
+        )
+        or (
+            python_ver_atleast_39
+            and origin in {list, dict, tuple, set, frozenset, deque, typing.Union}
+        )
     )
 
 
@@ -607,7 +619,8 @@ def add_annotations_to_class_dict(cls_dict):
             first_arg = getattr(v, "__args__", [0])[0]
             mros = getattr(first_arg, "__mro__", getattr(v, "__mro__", []))
             if not _type_is_generic(v) and (
-                    isinstance(v, (Field, Structure)) or Field in mros or Structure in mros):
+                isinstance(v, (Field, Structure)) or Field in mros or Structure in mros
+            ):
                 if k in cls_dict:
                     defaults[k] = cls_dict[k]
                 cls_dict[k] = v
@@ -617,7 +630,7 @@ def add_annotations_to_class_dict(cls_dict):
                     from .fields import AnyOf
 
                     if isinstance(the_type, AnyOf) and getattr(
-                            the_type, "_is_optional", False
+                        the_type, "_is_optional", False
                     ):
                         optional_fields.add(k)
                     if k in cls_dict:
@@ -741,20 +754,20 @@ class Structure(UniqueMixin, metaclass=StructMeta):
                 raise ValueError("Structure is immutable")
             value = deepcopy(value)
         if all(
-                [
-                    getattr(self, IGNORE_NONE_VALUES, False),
-                    value is None,
-                    key not in getattr(self.__class__, REQUIRED_FIELDS, []),
-                ]
+            [
+                getattr(self, IGNORE_NONE_VALUES, False),
+                value is None,
+                key not in getattr(self.__class__, REQUIRED_FIELDS, []),
+            ]
         ):
             return
 
         super().__setattr__(key, value)
 
         if (
-                getattr(self, "_instantiated", False)
-                and not _is_dunder(key)
-                and not _is_sunder(key)
+            getattr(self, "_instantiated", False)
+            and not _is_dunder(key)
+            and not _is_sunder(key)
         ):
             self.__manage_uniqueness__()
 
@@ -790,7 +803,7 @@ class Structure(UniqueMixin, metaclass=StructMeta):
 
         name = self.__class__.__name__
         if name.startswith("StructureReference_") and self.__class__.__bases__ == (
-                Structure,
+            Structure,
         ):
             name = "Structure"
         props = []
@@ -801,6 +814,9 @@ class Structure(UniqueMixin, metaclass=StructMeta):
                 props.append("{} = {}".format(k, strv))
         return "<Instance of {}. Properties: {}>".format(name, ", ".join(props))
 
+    def __repr__(self):
+        return self.__str__()
+
     def __eq__(self, other):
         if self.__class__ != other.__class__:
             return False
@@ -821,7 +837,7 @@ class Structure(UniqueMixin, metaclass=StructMeta):
 
     def __delitem__(self, key):
         if isinstance(getattr(self, REQUIRED_FIELDS), list) and key in getattr(
-                self, REQUIRED_FIELDS
+            self, REQUIRED_FIELDS
         ):
             raise ValueError("{} is mandatory".format(key))
         del self.__dict__[key]
@@ -866,9 +882,9 @@ class Structure(UniqueMixin, metaclass=StructMeta):
         required = props.get(REQUIRED_FIELDS, field_names)
         additional_props = props.get(ADDITIONAL_PROPERTIES, True)
         if (
-                len(field_names) == 1
-                and required == field_names
-                and additional_props is False
+            len(field_names) == 1
+            and required == field_names
+            and additional_props is False
         ):
             return item in getattr(self, field_names[0], {})
 
@@ -878,7 +894,13 @@ class Structure(UniqueMixin, metaclass=StructMeta):
 
     def shallow_clone_with_overrides(self, **kw):
         fields_names = self.get_all_fields_by_name().keys()
-        field_value_by_name = dict([(f, getattr(self, f)) for f in fields_names if getattr(self, f) is not None])
+        field_value_by_name = dict(
+            [
+                (f, getattr(self, f))
+                for f in fields_names
+                if getattr(self, f) is not None
+            ]
+        )
         kw_args = {**field_value_by_name, **kw}
         return self.__class__(**kw_args)
 
